Stan Math Library: stan/math/prim/mat/fun/corr_matrix_constrain.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
corr_matrix_constrain.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/meta/index_type.hpp>`
`#include <stan/math/prim/scal/fun/corr_constrain.hpp>`
`#include <stan/math/prim/mat/fun/read_corr_matrix.hpp>`
`#include <stdexcept>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > | stan::math::corr_matrix_constrain (const Eigen::Matrix< T, Eigen::Dynamic, 1 > &x, typename math::index_type< Eigen::Matrix< T, Eigen::Dynamic, 1 > >::type k)
| Return the correlation matrix of the specified dimensionality derived from the specified vector of unconstrained values. More...
template<typename T >
Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > | stan::math::corr_matrix_constrain (const Eigen::Matrix< T, Eigen::Dynamic, 1 > &x, typename math::index_type< Eigen::Matrix< T, Eigen::Dynamic, 1 > >::type k, T &lp)
| Return the correlation matrix of the specified dimensionality derived from the specified vector of unconstrained values. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.